import { IdInterface } from './contract';
import { ClassSchema } from '@deepkit/type';
import { ClassType } from '@deepkit/core';
export declare enum FileMode {
    closed = 0,
    streaming = 1
}
export declare class DeepkitFile implements IdInterface {
    /**
     * Path WITHOUT starting slash /;
     * e.g.
     *
     *    model.py
     *    .deepkit/log/master.txt
     */
    path: string;
    id: string;
    version: number;
    mode: FileMode;
    md5?: string;
    size: number;
    created: Date;
    updated: Date;
    constructor(
    /**
     * Path WITHOUT starting slash /;
     * e.g.
     *
     *    model.py
     *    .deepkit/log/master.txt
     */
    path: string);
    getMd5(): string;
    getFullPath(): string;
    getName(): string;
    /**
     * Returns always leading slash and trailing slash.
     */
    getDirectory(): string;
    /**
     * Name without slashes.
     */
    getDirectoryName(): string;
    /**
     * Checks whether this file is in given directory.
     *
     * @param dir with leading slash and trailing slash. Same as getDirectory().
     */
    inDirectory(dir?: string): boolean;
}
export declare class FileType<T extends DeepkitFile> {
    readonly classType: ClassType<T>;
    readonly classSchema: ClassSchema<T>;
    constructor(classType: ClassType<T>);
    static forDefault(): FileType<DeepkitFile>;
    static forCustomType<T extends DeepkitFile>(classType: ClassType<T>): FileType<T>;
    fork(file: T, newPath: string): T;
}
