import { BehaviorSubject } from 'rxjs';
export declare class ItemObserver<T> extends BehaviorSubject<T | undefined> {
    /**
     * The older snapshot at against we test for changes. reset() resets that.
     */
    protected old?: {
        [path: string]: any;
    };
    /**
     * The user operates on this object, which is a snapshot of the version upon initialisation.
     */
    protected _snapshot?: T;
    protected valueOrSubject?: T | BehaviorSubject<any>;
    readonly ignore: string[];
    constructor(value?: T | BehaviorSubject<any>);
    static fromValueOrSubject<T>(valueOrSubject: T | BehaviorSubject<T>, ignore?: string[]): ItemObserver<T>;
    /**
     * After creating an ItemObserver, the user requires to operate on this object. Otherwise changes are not detected.
     */
    get snapshot(): T;
    start(valueOrSubject: T | BehaviorSubject<T>): void;
    get original(): T | undefined;
    createState(): {
        [path: string]: any;
    };
    changed(): boolean;
    /**
     * Returns the plain patch values, key value.
     */
    private normalizePatch;
    /**
     * Returns class values of patches.
     */
    getPatchesAndReset(): {
        [name: string]: any;
    } | undefined;
    /**
     * Returns plain values of patches.
     */
    getPatches(): {
        [path: string]: any;
    } | undefined;
    /**
     * Returns plain values of patches.
     */
    getRawPatches(): {
        [path: string]: any;
    } | undefined;
    /**
     * Applies all detected changes to the original object.
     */
    applyAndReset(): void;
    /**
     * Resets all changes.
     */
    reset(): void;
}
/**
 * Returns patches in plain parameters.
 * @deprecated Use custom patch building.
 */
export declare function observeItem<T>(valueOrSubject: T | BehaviorSubject<T>, ignore?: string[]): ItemObserver<T>;
