"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("jest-extended");
require("reflect-metadata");
const core_1 = require("@deepkit/core");
const observer_1 = require("../src/observer");
const entities_1 = require("./entities");
const core_2 = require("../src/core");
test('watch apply', () => {
    new entities_1.Job('1231', '12344');
    const original = new entities_1.Job('1231', '12344');
    const observer = observer_1.observeItem(original);
    const job = observer.snapshot;
    job.iterations = 24;
    job.tasks['newone'] = new entities_1.JobTask('newone', 1);
    const patches = observer.getPatches();
    expect(core_1.size(patches)).toBe(2);
    expect(patches['iterations']).toBe(24);
    expect(patches['tasks.newone']).toBeInstanceOf(entities_1.JobTask);
    expect(original.iterations).toBe(0);
    expect(original.tasks['newone']).toBeUndefined();
    observer.applyAndReset();
    expect(observer.getPatches()).toBeUndefined();
    expect(original.iterations).toBe(24);
    expect(job.tasks['newone']).toBeInstanceOf(entities_1.JobTask);
});
test('watch', () => {
    new entities_1.Job('1231', '12344');
    const observer = observer_1.observeItem(new entities_1.Job('1231', '12344'));
    const job = observer.snapshot;
    job.iterations = 24;
    job.tasks['newone'] = new entities_1.JobTask('newone', 1);
    job.config.ignore.push('asd');
    job.config.ignore.push('12e1');
    job.ended = new Date;
    expect(observer.changed()).toBe(true);
    const rawPatches = observer.getRawPatches();
    expect(rawPatches['iterations']).toBe(24);
    expect(rawPatches['ended']).toBe(job.ended.toJSON());
    expect(rawPatches['tasks.newone']).not.toBeInstanceOf(entities_1.JobTask);
    const patches = observer.getPatchesAndReset();
    expect(core_1.size(patches)).toBe(5);
    expect(patches['iterations']).toBe(24);
    expect(patches['ended']).toBe(job.ended);
    expect(patches['tasks.newone']).toBeInstanceOf(entities_1.JobTask);
    expect(patches['tasks.newone']).toBe(job.tasks['newone']);
    expect(patches['config.ignore.0']).toBe('asd');
    expect(patches['config.ignore.1']).toBe('12e1');
    job.tasks['newone'].status = entities_1.JobTaskStatus.queued;
    const patches2 = observer.getPatchesAndReset();
    expect(core_1.size(patches2)).toBe(1);
    expect(patches2['tasks.newone.status']).toBe(entities_1.JobTaskStatus.queued);
    expect(observer.getPatchesAndReset()).toBeUndefined();
});
test('watch EntitySubject', () => {
    const observer = observer_1.observeItem(new core_2.EntitySubject(new entities_1.Job('1231', '12344')));
    const job = observer.snapshot;
    job.iterations = 24;
    job.tasks['newone'] = new entities_1.JobTask('newone', 1);
    job.config.ignore.push('asd');
    job.config.ignore.push('12e1');
    job.ended = new Date;
    expect(observer.changed()).toBe(true);
    const patches = observer.getPatchesAndReset();
    expect(core_1.size(patches)).toBe(5);
    expect(patches['iterations']).toBe(24);
    expect(patches['ended']).toBe(job.ended);
    expect(patches['tasks.newone']).toBe(job.tasks['newone']);
    expect(patches['config.ignore.0']).toBe('asd');
    expect(patches['config.ignore.1']).toBe('12e1');
    job.tasks['newone'].status = entities_1.JobTaskStatus.queued;
    const patches2 = observer.getPatchesAndReset();
    expect(core_1.size(patches2)).toBe(1);
    expect(patches2['tasks.newone.status']).toBe(entities_1.JobTaskStatus.queued);
    expect(observer.getPatchesAndReset()).toBeUndefined();
});
//# sourceMappingURL=observer.spec.js.map